@@ -1,6 +1,9 @@
 package ai
 
 import (
+	"io"
+	"os"
+	"strings"
 	"testing"
 )
 
@@ -31,3 +34,23 @@ func TestFindVendorsByModel(t *testing.T) {
 		t.Fatalf("FindVendorsByModel() = %v, want %v", foundVendors, []string{"vendor1"})
 	}
 }
+
+func TestPrintWithVendorMarksDefault(t *testing.T) {
+	vendors := NewVendorsModels()
+	vendors.AddGroupItems("vendor1", []string{"model1"}...)
+	vendors.AddGroupItems("vendor2", []string{"model2"}...)
+
+	r, w, _ := os.Pipe()
+	oldStdout := os.Stdout
+	os.Stdout = w
+
+	vendors.PrintWithVendor(false, "vendor2", "model2")
+
+	w.Close()
+	os.Stdout = oldStdout
+	out, _ := io.ReadAll(r)
+
+	if !strings.Contains(string(out), "      *\t[2]\tvendor2|model2") {
+		t.Fatalf("default model not marked: %s", out)
+	}
+}
