@@ -115,7 +115,11 @@ func (o *Client) sendStreamResponses(
 		case string(constant.ResponseOutputTextDelta("").Default()):
 			channel <- event.AsResponseOutputTextDelta().Delta
 		case string(constant.ResponseOutputTextDone("").Default()):
-			channel <- event.AsResponseOutputTextDone().Text
+			// The Responses API sends the full text again in the
+			// final "done" event. Since we've already streamed all
+			// delta chunks above, sending it would duplicate the
+			// output. Ignore it here to prevent doubled results.
+			continue
 		}
 	}
 	if stream.Err() == nil {
@@ -180,6 +184,19 @@ func (o *Client) NeedsRawMode(modelName string) bool {
 	return slices.Contains(openAIModelsNeedingRaw, modelName)
 }
 
+func parseReasoningEffort(level domain.ThinkingLevel) (shared.ReasoningEffort, bool) {
+	switch domain.ThinkingLevel(strings.ToLower(string(level))) {
+	case domain.ThinkingLow:
+		return shared.ReasoningEffortLow, true
+	case domain.ThinkingMedium:
+		return shared.ReasoningEffortMedium, true
+	case domain.ThinkingHigh:
+		return shared.ReasoningEffortHigh, true
+	default:
+		return "", false
+	}
+}
+
 func (o *Client) buildResponseParams(
 	inputMsgs []*chat.ChatCompletionMessage, opts *domain.ChatOptions,
 ) (ret responses.ResponseNewParams) {
@@ -225,6 +242,10 @@ func (o *Client) buildResponseParams(
 		ret.Tools = tools
 	}
 
+	if eff, ok := parseReasoningEffort(opts.Thinking); ok {
+		ret.Reasoning = shared.ReasoningParam{Effort: eff}
+	}
+
 	if !opts.Raw {
 		ret.Temperature = openai.Float(opts.Temperature)
 		if opts.TopP != 0 {
